@@ -1,6 +1,6 @@
 /*
  *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.h,v 1.8 2003/12/07 10:23:31 chpe Exp $
+ *  $Id: ephy-dialog.h,v 1.10.4.1 2004/04/05 17:52:17 chpe Exp $
  */
 
 #ifndef EPHY_DIALOG_H
@@ -66,7 +66,8 @@ struct EphyDialogClass
 	void	(* construct)	(EphyDialog *dialog,
 				 const EphyDialogProperty *properties,
 				 const char *file,
-				 const char *name);
+				 const char *name,
+				 const char *domain);
 	void	(* show)	(EphyDialog *dialog);
 };
 
@@ -87,7 +88,8 @@ EphyDialog     *ephy_dialog_new_with_parent	(GtkWidget *parent_window);
 void		ephy_dialog_construct		(EphyDialog *dialog,
 						 const EphyDialogProperty *properties,
 						 const char *file,
-						 const char *name);
+						 const char *name,
+						 const char *domain);
 
 void		ephy_dialog_add_enum		(EphyDialog *dialog,
 						 const char *id,
@@ -106,6 +108,13 @@ int		ephy_dialog_run			(EphyDialog *dialog);
 
 void		ephy_dialog_show		(EphyDialog *dialog);
 
+void		ephy_dialog_hide		(EphyDialog *dialog);
+
+void		ephy_dialog_set_parent		(EphyDialog *dialog,
+						 GtkWidget *parent);
+
+GtkWidget      *ephy_dialog_get_parent		(EphyDialog *dialog);
+
 void		ephy_dialog_set_modal		(EphyDialog *dialog,
 						 gboolean is_modal);
 
