@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-notebook.c,v 1.32 2004/03/06 19:02:38 chpe Exp $
+ *  $Id: ephy-notebook.c,v 1.32.4.1 2004/04/02 22:33:03 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -669,7 +669,7 @@ notebook_drag_data_received_cb (GtkWidget* widget, GdkDragContext *context,
 	g_return_if_fail (EPHY_IS_WINDOW (toplevel));
 	window = EPHY_WINDOW (toplevel);
 
-	if (tab != NULL);
+	if (tab != NULL)
 	{
 		embed = ephy_tab_get_embed (tab);
 		g_return_if_fail (EPHY_IS_EMBED (embed));
